@@ -480,7 +480,9 @@ void process_fields(int ch)
 		wrefresh(fields_win);
 		break;
 	case KEY_BACKSPACE:
+	case KEY_DC:
 	case 127:
+	case 8:
 		LOG("Backspace\n");
 		form_driver(form, REQ_DEL_CHAR);
 		form_driver(form, REQ_DEL_PREV);
@@ -491,7 +493,7 @@ void process_fields(int ch)
 		wrefresh(fields_win);
 		break;
 	default:
-		LOG("default char\n");
+		LOG("default char: %d\n", ch);
 
 		tmp_field = current_field(form);
 		cur_base = field_userptr(tmp_field);
@@ -649,7 +651,6 @@ int start_interactive(uint64_t start)
 			}
 			break;
 
-				
 		case KEY_F(1):
 			unpaint_screen();
 			show_help();
@@ -696,6 +697,21 @@ int start_interactive(uint64_t start)
 			g_val = ~g_val & MASK(g_width);
 			paint_screen();
 			break;
+		case 'r':
+			unpaint_screen();
+			switch (g_width) {
+				case 16:
+					g_val = __builtin_bswap16(g_val);
+					break;
+				case 32:
+					g_val = __builtin_bswap32(g_val);
+					break;
+				case 64:
+					g_val = __builtin_bswap64(g_val);
+					break;
+			}
+			paint_screen();
+			break;
 		case '>':
 			unpaint_screen();
 			g_val = g_val >> 1;
@@ -720,6 +736,9 @@ int start_interactive(uint64_t start)
 			} else if (last_win == BINARY_WIN)
 				position_binary_curser(bit_pos, -1);
 
+			// Stop handling of mouse events
+			mousemask(0, NULL);
+
 			curs_set(1);
 			keypad(stdscr, FALSE);
 			intrflush(NULL, FALSE);
